'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.screenshot = exports.update = exports.off = exports.on = exports.getCurrentScreens = exports.getCurrentScreenState = undefined;

var _nightingale = require('nightingale');

var _nightingale2 = _interopRequireDefault(_nightingale);

var _exec = require('./exec');

var _client = require('../client');

var _display = require('./display');

var display = _interopRequireWildcard(_display);

var _screensaver = require('./screensaver');

var screensaver = _interopRequireWildcard(_screensaver);

var _flowRuntime = require('flow-runtime');

var _flowRuntime2 = _interopRequireDefault(_flowRuntime);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const logger = new _nightingale2.default('app:commands:screen');

const ScreenStateType = _flowRuntime2.default.type('ScreenStateType', _flowRuntime2.default.union(_flowRuntime2.default.string('on'), _flowRuntime2.default.string('off'), _flowRuntime2.default.string('unavailable')));

const getScreens = () => {
  const _returnType = _flowRuntime2.default.return(_flowRuntime2.default.array(_flowRuntime2.default.string()));

  return _returnType.assert((0, _exec.runSyncAsUser)('./screen.sh', ['screens']).split('\n').filter(Boolean));
};

let _currentScreensType = _flowRuntime2.default.array(_flowRuntime2.default.string()),
    currentScreens = _currentScreensType.assert(getScreens());

const getScreenState = () => {
  const _returnType2 = _flowRuntime2.default.return(ScreenStateType);

  return _returnType2.assert(currentScreens.length === 0 ? 'unavailable' : (0, _exec.runSyncAsUser)('./screen.sh', ['state']));
};

let _currentScreenStateType = ScreenStateType,
    currentScreenState = _currentScreenStateType.assert(getScreenState());

logger.info('init', { currentScreens, currentScreenState });

const filterTouchscreenIfHasHdmi = screens => {
  if (screens.length < 2) return screens;

  if (screens.some(screen => screen.startsWith('HDMI'))) {
    return screens.filter(screen => !screen.startsWith('HDMI'));
  }

  return screens;
};

const updateCurrentScreenState = () => {
  currentScreens = _currentScreensType.assert(getScreens());
  const state = getScreenState();

  if (currentScreenState !== state) {
    currentScreenState = _currentScreenStateType.assert(state);
    (0, _client.sendUpdate)({
      screenState: currentScreenState,
      screen: { state: currentScreenState, screens: currentScreens }
    });
  }
};

// const turnOnScreen = (screen: string) =>
//   runSyncAsUser('xrandr', ['--display', ':0', '--output', screen, '--auto']);

const turnOffScreen = screen => {
  let _screenType = _flowRuntime2.default.string();

  _flowRuntime2.default.param('screen', _screenType).assert(screen);

  return (0, _exec.runSyncAsUser)('xrandr', ['--display', ':0', '--output', screen, '--off']);
};

const turnScreen = state => {
  let _stateType = _flowRuntime2.default.union(_flowRuntime2.default.string('on'), _flowRuntime2.default.string('off'));

  _flowRuntime2.default.return(_flowRuntime2.default.void());

  _flowRuntime2.default.param('state', _stateType).assert(state);

  (0, _exec.runSyncAsUser)('./screen.sh', [state]);

  if (state === 'on') {
    const screensWithoutTouchscreenIfHdmi = filterTouchscreenIfHasHdmi(currentScreens);

    if (screensWithoutTouchscreenIfHdmi.length !== currentScreens.length) {
      currentScreens.filter(screen => screensWithoutTouchscreenIfHdmi.includes(screen)).forEach(turnOffScreen);
    }

    // screensWithoutTouchscreenIfHdmi.forEach(turnOnScreen);
  }
};

const getCurrentScreenState = exports.getCurrentScreenState = () => {
  const _returnType4 = _flowRuntime2.default.return(ScreenStateType);

  return _returnType4.assert(currentScreenState);
};
const getCurrentScreens = exports.getCurrentScreens = () => {
  const _returnType5 = _flowRuntime2.default.return(_flowRuntime2.default.array(_flowRuntime2.default.string()));

  return _returnType5.assert(currentScreens);
};

const on = exports.on = (autoStartDisplay = true) => {
  _flowRuntime2.default.return(_flowRuntime2.default.void());

  logger.info('turning screen on');
  turnScreen('on');
  if (autoStartDisplay) display.start();
};

const off = exports.off = () => {
  _flowRuntime2.default.return(_flowRuntime2.default.void());

  logger.info('turning screen off');
  display.stop();
  turnScreen('off');
};

const update = exports.update = (config, firstTime = false) => {
  let _configType = _flowRuntime2.default.object();

  _flowRuntime2.default.param('config', _configType).assert(config);

  if (!display.supports(config)) return off();

  if (firstTime) (0, _exec.runSyncAsUser)('./screen.sh', ['waitForX']);

  screensaver.update(config);
  updateCurrentScreenState();

  if (currentScreenState === 'on') {
    if (firstTime) on(false);
    display.update(config);
  }
};

const screenshot = exports.screenshot = () => {
  if (currentScreenState !== 'on') {
    logger.debug('screenshot: screen is not on');
    return;
  }

  logger.info('getting screenshot');
  return (0, _exec.runPipeAsUser)('./screen.sh', ['screenshot']);
};
//# sourceMappingURL=screen.js.map